#############################################################################################
#                                                                                           #
# Author:   GeoPy Team                                                                      #
# Email:    geopy.info@gmail.com                                                            #
# Date:     January 2019                                                                    #
#                                                                                           #
#############################################################################################

# Create a window for managing pre-stack seismic


from PyQt5 import QtCore, QtGui, QtWidgets
import os, sys
#
sys.path.append(os.path.dirname(__file__)[:-4][:-4][:-13])
from cognitivegeo.src.core.settings import settings as core_set
from cognitivegeo.src.psseismic.analysis import analysis as psseis_ays
from cognitivegeo.src.gui.editpsseis import editpsseis as gui_editpsseis
from cognitivegeo.src.vis.messager import messager as vis_msg

QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)


class managepsseis(object):

    psseisdata = {}
    plotstyle = core_set.Visual['Image']
    fontstyle = core_set.Visual['Font']
    #
    iconpath = os.path.dirname(__file__)
    dialog = None


    def setupGUI(self, ManagePsSeis):
        ManagePsSeis.setObjectName("ManagePsSeis")
        ManagePsSeis.setFixedSize(320, 420)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(os.path.join(self.iconpath, "icons/psseismic.png")),
                       QtGui.QIcon.Normal,
                       QtGui.QIcon.Off)
        ManagePsSeis.setWindowIcon(icon)
        #
        self.lblpsseis = QtWidgets.QLabel(ManagePsSeis)
        self.lblpsseis.setObjectName("lblpsseis")
        self.lblpsseis.setGeometry(QtCore.QRect(10, 10, 150, 30))
        self.twgpsseis = QtWidgets.QTableWidget(ManagePsSeis)
        self.twgpsseis.setObjectName("twgpsseis")
        self.twgpsseis.setGeometry(QtCore.QRect(10, 50, 300, 300))
        self.twgpsseis.setColumnCount(2)
        self.twgpsseis.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.twgpsseis.verticalHeader().hide()
        self.btnedit = QtWidgets.QPushButton(ManagePsSeis)
        self.btnedit.setObjectName("btnedit")
        self.btnedit.setGeometry(QtCore.QRect(210, 360, 100, 30))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(os.path.join(self.iconpath, "icons/pen.png")),
                       QtGui.QIcon.Normal,
                       QtGui.QIcon.Off)
        self.btnedit.setIcon(icon)
        #
        self.msgbox = QtWidgets.QMessageBox(ManagePsSeis)
        self.msgbox.setObjectName("msgbox")
        _center_x = ManagePsSeis.geometry().center().x()
        _center_y = ManagePsSeis.geometry().center().y()
        self.msgbox.setGeometry(QtCore.QRect(_center_x - 150, _center_y - 50, 300, 100))
        #
        self.retranslateGUI(ManagePsSeis)
        QtCore.QMetaObject.connectSlotsByName(ManagePsSeis)


    def retranslateGUI(self, ManagePsSeis):
        self.dialog = ManagePsSeis
        #
        _translate = QtCore.QCoreApplication.translate
        ManagePsSeis.setWindowTitle(_translate("ManagePsSeis", "Manage Pre-stack Seismic"))
        self.lblpsseis.setText(_translate("ManagePsSeis", "Available pre-stack seismic:"))
        self.btnedit.setText(_translate("ManagePsSeis", "Edit"))
        self.btnedit.setToolTip("Edit pre-stack seismic")
        self.btnedit.clicked.connect(self.clickBtnEdit)
        #
        self.refreshTwgPsSeis()

    def clickBtnEdit(self):
        _edit = QtWidgets.QDialog()
        _gui = gui_editpsseis()
        _gui.psseisdata = self.psseisdata
        _gui.plotstyle = self.plotstyle
        _gui.fontstyle = self.fontstyle
        _gui.setupGUI(_edit)
        _edit.exec()
        self.psseisdata = _gui.psseisdata
        _edit.show()
        #
        self.refreshTwgPsSeis()


    def refreshTwgPsSeis(self):
        self.twgpsseis.clear()
        self.twgpsseis.setHorizontalHeaderLabels(["Name", "No. of shots"])
        if len(self.psseisdata.keys()) > 0:
            _idx = 0
            self.twgpsseis.setRowCount(len(self.psseisdata.keys()))
            for i in sorted(self.psseisdata.keys()):
                if self.checkPsSeis(i):
                    item = QtWidgets.QTableWidgetItem()
                    item.setText(i)
                    item.setFlags(QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled)
                    self.twgpsseis.setItem(_idx, 0, item)
                    item = QtWidgets.QTableWidgetItem()
                    item.setText(str(len(list(self.psseisdata[i].keys()))))
                    item.setTextAlignment(QtCore.Qt.AlignCenter)
                    item.setFlags(QtCore.Qt.ItemIsEditable)
                    self.twgpsseis.setItem(_idx, 1, item)
                    _idx = _idx + 1
            self.twgpsseis.setRowCount(_idx)


    def refreshMsgBox(self):
        _center_x = self.dialog.geometry().center().x()
        _center_y = self.dialog.geometry().center().y()
        self.msgbox.setGeometry(QtCore.QRect(_center_x - 150, _center_y - 50, 300, 100))


    def checkPsSeis(self, name):
        return psseis_ays.checkPsSeis(self.psseisdata[name])


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    ManagePsSeis = QtWidgets.QWidget()
    gui = managepsseis()
    gui.setupGUI(ManagePsSeis)
    ManagePsSeis.show()
    sys.exit(app.exec_())


#############################################################################################
#                                                                                           #
# Author:   GeoPy Team                                                                      #
# Email:    geopy.info@gmail.com                                                            #
# Date:     August 2018                                                                     #
#                                                                                           #
#############################################################################################

# Create a window for filtering pointset based on properties


from PyQt5 import QtCore, QtGui, QtWidgets
import os, sys
#
sys.path.append(os.path.dirname(__file__)[:-4][:-4][:-13])
from cognitivegeo.src.basic.data import data as basic_data
from cognitivegeo.src.basic.matdict import matdict as basic_mdt
from cognitivegeo.src.vis.messager import messager as vis_msg

QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)


class filterpointset(object):

    pointsetname = ''
    pointsetdata = {}
    rootpath = ''
    #
    iconpath = os.path.dirname(__file__)
    dialog = None


    def setupGUI(self, FilterPointSet):
        FilterPointSet.setObjectName("FilterPointSet")
        FilterPointSet.setFixedSize(300, 420)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(os.path.join(self.iconpath, "icons/filter.png")),
                       QtGui.QIcon.Normal,
                       QtGui.QIcon.Off)
        FilterPointSet.setWindowIcon(icon)
        #
        self.lblattrib = QtWidgets.QLabel(FilterPointSet)
        self.lblattrib.setObjectName("lblattrib")
        self.lblattrib.setGeometry(QtCore.QRect(10, 10, 150, 30))
        self.lwgattrib = QtWidgets.QListWidget(FilterPointSet)
        self.lwgattrib.setObjectName("lwgattrib")
        self.lwgattrib.setGeometry(QtCore.QRect(10, 50, 280, 200))
        self.lwgattrib.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.lblfilter = QtWidgets.QLabel(FilterPointSet)
        self.lblfilter.setObjectName("lblfilter")
        self.lblfilter.setGeometry(QtCore.QRect(90, 270, 60, 30))
        self.cbbfilter = QtWidgets.QComboBox(FilterPointSet)
        self.cbbfilter.setObjectName("cbbfilter")
        self.cbbfilter.setGeometry(QtCore.QRect(160, 270, 130, 30))
        self.lblvalue = QtWidgets.QLabel(FilterPointSet)
        self.lblvalue.setObjectName("lblvalue")
        self.lblvalue.setGeometry(QtCore.QRect(160, 310, 50, 30))
        self.ldtvalue = QtWidgets.QLineEdit(FilterPointSet)
        self.ldtvalue.setObjectName("ldtvalue")
        self.ldtvalue.setGeometry(QtCore.QRect(210, 310, 80, 30))
        self.btnapply = QtWidgets.QPushButton(FilterPointSet)
        self.btnapply.setObjectName("btnedit")
        self.btnapply.setGeometry(QtCore.QRect(100, 370, 100, 30))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(os.path.join(self.iconpath, "icons/ok.png")),
                       QtGui.QIcon.Normal,
                       QtGui.QIcon.Off)
        self.btnapply.setIcon(icon)
        #
        self.msgbox = QtWidgets.QMessageBox(FilterPointSet)
        self.msgbox.setObjectName("msgbox")
        _center_x = FilterPointSet.geometry().center().x()
        _center_y = FilterPointSet.geometry().center().y()
        self.msgbox.setGeometry(QtCore.QRect(_center_x - 150, _center_y - 50, 300, 100))
        #
        self.retranslateGUI(FilterPointSet)
        QtCore.QMetaObject.connectSlotsByName(FilterPointSet)


    def retranslateGUI(self, FilterPointSet):
        self.dialog = FilterPointSet
        #
        _translate = QtCore.QCoreApplication.translate
        FilterPointSet.setWindowTitle(_translate("FilterPointSet", "Filter PointSet " + self.pointsetname))
        self.lblattrib.setText(_translate("FilterPointSet", "List of available properties:"))
        self.lblfilter.setText(_translate("FilterPointSet", "Select filter:"))
        self.cbbfilter.addItems(['>= value', '<= value', '== value', '> value', '< value', '!= value'])
        self.cbbfilter.setCurrentIndex(2)
        self.lblvalue.setText(_translate("FilterPointSet", "value ="))
        self.ldtvalue.setText(_translate("FilterPointSet", ""))
        self.btnapply.setText(_translate("FilterPointSet", "Apply"))
        self.btnapply.clicked.connect(self.clickBtnApply)
        #
        self.refreshLwgAttrib()


    def clickBtnApply(self):
        self.refreshMsgBox()
        #
        _attriblist = self.lwgattrib.selectedItems()
        if len(_attriblist) < 1:
            vis_msg.print("ERROR in FilterPointSet: No property selected for filtering", type='error')
            QtWidgets.QMessageBox.critical(self.msgbox,
                                           'Filter PointSet',
                                           'No property selected for filtering')
            return
        _value = basic_data.str2float(self.ldtvalue.text())
        if _value is False:
            vis_msg.print("ERROR in FilterPointSet: Non-float value specified for filtering", type='error')
            QtWidgets.QMessageBox.critical(self.msgbox,
                                           'Filter PointSet',
                                           'Non-float value specified for filtering')
            return
        #
        _flag = '=='
        if self.cbbfilter.currentIndex() == 0:
            _flag = '>='
        if self.cbbfilter.currentIndex() == 1:
            _flag = '<='
        if self.cbbfilter.currentIndex() == 2:
            _flag = '=='
        if self.cbbfilter.currentIndex() == 3:
            _flag = '>'
        if self.cbbfilter.currentIndex() == 4:
            _flag = '<'
        if self.cbbfilter.currentIndex() == 5:
            _flag = '!='
        self.pointsetdata = basic_mdt.filterDictByValue(self.pointsetdata,
                                                     key=_attriblist[0].text(),
                                                     value=_value,
                                                     flag=_flag)
        #
        # QtWidgets.QMessageBox.information(self.msgbox,
        #                                   "Edit Seismic/PointSet",
        #                                   "Seismic/PointSet property edited successfully")
        self.dialog.close()
        return


    def refreshLwgAttrib(self):
        self.lwgattrib.clear()
        if len(self.pointsetdata.keys()) > 0:
            for i in sorted(self.pointsetdata.keys()):
                if i != "Inline" and i != "Crossline" and i != "Z":
                    item = QtWidgets.QListWidgetItem(self.lwgattrib)
                    item.setText(i)
                    self.lwgattrib.addItem(item)
            if "Inline" in self.pointsetdata.keys():
                item = QtWidgets.QListWidgetItem(self.lwgattrib)
                item.setText("Inline")
                self.lwgattrib.addItem(item)
            if "Crossline" in self.pointsetdata.keys():
                item = QtWidgets.QListWidgetItem(self.lwgattrib)
                item.setText("Crossline")
                self.lwgattrib.addItem(item)
            if "Z" in self.pointsetdata.keys():
                item = QtWidgets.QListWidgetItem(self.lwgattrib)
                item.setText("Z")
                self.lwgattrib.addItem(item)


    def refreshMsgBox(self):
        _center_x = self.dialog.geometry().center().x()
        _center_y = self.dialog.geometry().center().y()
        self.msgbox.setGeometry(QtCore.QRect(_center_x - 150, _center_y - 50, 300, 100))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FilterPointSet = QtWidgets.QWidget()
    gui = filterpointset()
    gui.setupGUI(FilterPointSet)
    FilterPointSet.show()
    sys.exit(app.exec_())


#############################################################################################
#                                                                                           #
# Author:   GeoPy Team                                                                      #
# Email:    geopy.info@gmail.com                                                            #
# Date:     March 2018                                                                      #
#                                                                                           #
#############################################################################################

# Create a window for exporting seismic segys


from PyQt5 import QtCore, QtGui, QtWidgets
import numpy as np
import os, sys
#
sys.path.append(os.path.dirname(__file__)[:-4][:-4][:-13])
from cognitivegeo.src.seismic.inputoutput import inputoutput as seis_io
from cognitivegeo.src.seismic.analysis import analysis as seis_ays
from cognitivegeo.src.vis.messager import messager as vis_msg

QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)


class exportseissegy(object):

    survinfo = {}
    seisdata = {}
    rootpath = ''
    #
    iconpath = os.path.dirname(__file__)
    dialog = None

    def setupGUI(self, ExportSeisSegy):
        ExportSeisSegy.setObjectName("ExportSeisSegy")
        ExportSeisSegy.setFixedSize(400, 470)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(os.path.join(self.iconpath, "icons/segy.png")),
                       QtGui.QIcon.Normal,
                       QtGui.QIcon.Off)
        ExportSeisSegy.setWindowIcon(icon)
        #
        self.lblattrib = QtWidgets.QLabel(ExportSeisSegy)
        self.lblattrib.setObjectName("lblattrib")
        self.lblattrib.setGeometry(QtCore.QRect(10, 10, 150, 30))
        self.lwgattrib = QtWidgets.QListWidget(ExportSeisSegy)
        self.lwgattrib.setObjectName("lwgattrib")
        self.lwgattrib.setGeometry(QtCore.QRect(160, 10, 230, 200))
        self.lwgattrib.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.lblsurvey = QtWidgets.QLabel(ExportSeisSegy)
        self.lblsurvey.setObjectName("lblsurvey")
        self.lblsurvey.setGeometry(QtCore.QRect(10, 230, 150, 30))
        self.rdbsurveynew = QtWidgets.QRadioButton(ExportSeisSegy)
        self.rdbsurveynew.setObjectName("rdbsurvey")
        self.rdbsurveynew.setGeometry(QtCore.QRect(10, 270, 190, 30))
        self.rdbsurveyref = QtWidgets.QRadioButton(ExportSeisSegy)
        self.rdbsurveyref.setObjectName("rdbsurvey")
        self.rdbsurveyref.setGeometry(QtCore.QRect(200, 270, 190, 30))
        self.ldtsurveyref = QtWidgets.QLineEdit(ExportSeisSegy)
        self.ldtsurveyref.setObjectName("ldtsurveyref")
        self.ldtsurveyref.setGeometry(QtCore.QRect(10, 310, 310, 30))
        self.btnsurveyref = QtWidgets.QPushButton(ExportSeisSegy)
        self.btnsurveyref.setObjectName("btnsurveyref")
        self.btnsurveyref.setGeometry(QtCore.QRect(330, 310, 60, 30))
        self.lblsave = QtWidgets.QLabel(ExportSeisSegy)
        self.lblsave.setObjectName("lblsave")
        self.lblsave.setGeometry(QtCore.QRect(10, 360, 50, 30))
        self.ldtsave = QtWidgets.QLineEdit(ExportSeisSegy)
        self.ldtsave.setObjectName("ldtsave")
        self.ldtsave.setGeometry(QtCore.QRect(70, 360, 250, 30))
        self.btnsave = QtWidgets.QPushButton(ExportSeisSegy)
        self.btnsave.setObjectName("btnsave")
        self.btnsave.setGeometry(QtCore.QRect(330, 360, 60, 30))
        self.btnexportsegy = QtWidgets.QPushButton(ExportSeisSegy)
        self.btnexportsegy.setObjectName("btnexportsegy")
        self.btnexportsegy.setGeometry(QtCore.QRect(120, 410, 160, 30))
        self.btnexportsegy.setIcon(icon)
        #
        self.msgbox = QtWidgets.QMessageBox(ExportSeisSegy)
        self.msgbox.setObjectName("msgbox")
        _center_x = ExportSeisSegy.geometry().center().x()
        _center_y = ExportSeisSegy.geometry().center().y()
        self.msgbox.setGeometry(QtCore.QRect(_center_x - 150, _center_y - 50, 300, 100))
        #
        self.retranslateGUI(ExportSeisSegy)
        QtCore.QMetaObject.connectSlotsByName(ExportSeisSegy)


    def retranslateGUI(self, ExportSeisSegy):
        self.dialog = ExportSeisSegy
        #
        _translate = QtCore.QCoreApplication.translate
        ExportSeisSegy.setWindowTitle(_translate("ExportSeisSegy", "Export Seismic SEG-Y"))
        self.lblattrib.setText(_translate("ExportSeisSegy", "Select output properties:"))
        if self.checkSurvInfo() is True:
            _firstattrib = None
            for i in sorted(self.seisdata.keys()):
                if self.checkSeisData(i):
                    item = QtWidgets.QListWidgetItem(self.lwgattrib)
                    item.setText(_translate("ExportSeisSegy", i))
                    self.lwgattrib.addItem(item)
                    if _firstattrib is None:
                        _firstattrib = item
            self.lwgattrib.setCurrentItem(_firstattrib)
        self.lblsurvey.setText(_translate("ExportSeisSegy", "Setup output survey:"))
        self.rdbsurveynew.setText(_translate("ExportSeisSegy", "from input data dimensions"))
        self.rdbsurveynew.setChecked(True)
        self.rdbsurveynew.clicked.connect(self.clickRdbSurveyNew)
        self.rdbsurveyref.setText(_translate("ExportSeisSegy", "from a reference SEG-Y file"))
        self.rdbsurveyref.setChecked(False)
        self.rdbsurveyref.clicked.connect(self.clickRdbSurveyRef)
        self.ldtsurveyref.setText(_translate("ExportSeisSegy", ""))
        self.ldtsurveyref.setEnabled(False)
        self.btnsurveyref.setText(_translate("ExportSeisSegy", "Browse"))
        self.btnsurveyref.setEnabled(False)
        self.btnsurveyref.clicked.connect(self.clickBtnSurveyRef)
        self.lblsave.setText(_translate("ExportSeisSegy", "Save to:"))
        self.ldtsave.setText(_translate("ExportSeisSegy", os.path.abspath(self.rootpath)))
        self.btnsave.setText(_translate("ExportSeisSegy", "Browse"))
        self.btnsave.clicked.connect(self.clickBtnSave)
        self.btnexportsegy.setText(_translate("ExportSeisSegy", "Export Seismic SEG-Y"))
        self.btnexportsegy.clicked.connect(self.clickBtnExportSeisSegy)


    def clickRdbSurveyRef(self):
        if self.rdbsurveyref.isChecked():
            self.rdbsurveyref.setChecked(True)
            self.rdbsurveynew.setChecked(False)
            # self.ldtsurveyref.setText(os.path.abspath(self.rootpath))
            self.ldtsurveyref.setEnabled(True)
            self.btnsurveyref.setEnabled(True)


    def clickRdbSurveyNew(self):
        if self.rdbsurveynew.isChecked():
            self.rdbsurveyref.setChecked(False)
            self.rdbsurveynew.setChecked(True)
            self.ldtsurveyref.setText('')
            self.ldtsurveyref.setEnabled(False)
            self.btnsurveyref.setEnabled(False)


    def clickBtnSurveyRef(self):
        _dialog = QtWidgets.QFileDialog()
        _file = _dialog.getOpenFileName(None, 'Select Reference SEG-Y', self.rootpath,
                                        filter="SEG-Y files (*.segy; *.sgy);; All files (*.*)")
        if len(_file[0]) > 0:
            self.ldtsurveyref.setText(_file[0])


    def clickBtnSave(self):
        _dialog = QtWidgets.QFileDialog()
        _file = _dialog.getExistingDirectory(None, 'Select Export Folder', self.rootpath,
                                             options=QtWidgets.QFileDialog.DontUseNativeDialog)
        if len(_file) > 0:
            self.ldtsave.setText(_file)


    def clickBtnExportSeisSegy(self):
        self.refreshMsgBox()
        #
        _attriblist = self.lwgattrib.selectedItems()
        if len(_attriblist) < 1:
            vis_msg.print("ERROR in ExportSeisSegy: No property selected for export", type='error')
            QtWidgets.QMessageBox.critical(self.msgbox,
                                           'Export Seismic SEG-Y',
                                           'No property selected for export')
            return
        if self.rdbsurveyref.isChecked() and (os.path.exists(self.ldtsurveyref.text()) is False):
            vis_msg.print("ERROR in ExportSeisSegy: Reference SEG-Y not found", type='error')
            QtWidgets.QMessageBox.critical(self.msgbox,
                                           'Export Seismic SEG-Y',
                                           'Reference SEG-Y not found')
            return
        # Progress dialog
        _pgsdlg = QtWidgets.QProgressDialog()
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(os.path.join(self.iconpath, "icons/segy.png")),
                       QtGui.QIcon.Normal, QtGui.QIcon.Off)
        _pgsdlg.setWindowIcon(icon)
        _pgsdlg.setWindowTitle('Export Seismic SEG-Y')
        _pgsdlg.setCancelButton(None)
        _pgsdlg.setWindowFlags(QtCore.Qt.WindowStaysOnTopHint)
        _pgsdlg.forceShow()
        _pgsdlg.setFixedWidth(400)
        #
        for i in range(len(_attriblist)):
            #
            _pgsdlg.setWindowTitle('Export '+str(i+1)+' of '+str(len(_attriblist))+' Seismic SEG-Y')
            #
            _segyfile = os.path.join(self.ldtsave.text(),
                                     _attriblist[i].text() + '.segy')
            print("ExportSeisSegy: Export %d of %d SEG-Y: %s" % (i + 1, len(_attriblist), _segyfile))
            _data = self.seisdata[_attriblist[i].text()]
            if self.rdbsurveynew.isChecked():
                seis_io.writeSeis3DMatToSegyNoRef(_data, _segyfile,
                                                  inlstart=self.survinfo['ILStart'], inlstep=self.survinfo['ILStep'],
                                                  xlstart=self.survinfo['XLStart'], xlstep=self.survinfo['XLStep'],
                                                  zstart=self.survinfo['ZStart'], zstep=self.survinfo['ZStep'],
                                                  xcoorstart=self.survinfo['XLStart'], ycoorstart=self.survinfo['ILStart'],
                                                  inlbinsize=self.survinfo['ILStep'], xlbinsize=self.survinfo['XLStep'],
                                                  orientation=90,
                                                  verbose=False,
                                                  qpgsdlg=_pgsdlg)
            else:
                _reffile = self.ldtsurveyref.text()
                seis_io.writeSeis3DMatToSegyWithRef(_data, _segyfile, _reffile, verbose=False,
                                                    qpgsdlg=_pgsdlg)
        # _pgsdlg.setValue(len(_attriblist) * _tracenum)
        #
        QtWidgets.QMessageBox.information(self.msgbox,
                                          "Export Seismic SEG-Y",
                                          str(len(_attriblist)) + " properties exported as SEG-Y successfully")
        return


    def refreshMsgBox(self):
        _center_x = self.dialog.geometry().center().x()
        _center_y = self.dialog.geometry().center().y()
        self.msgbox.setGeometry(QtCore.QRect(_center_x - 150, _center_y - 50, 300, 100))


    def checkSurvInfo(self):
        self.refreshMsgBox()
        #
        if seis_ays.checkSeisInfo(self.survinfo) is False:
            # print("ExportSeisSegy: Survey not found")
            # QtWidgets.QMessageBox.critical(self.msgbox,
            #                                'Export Seismic SEG-Y',
            #                                'Survey not found')
            return False
        return True
        
        
    def checkSeisData(self, f):
        self.refreshMsgBox()
        #
        return seis_ays.isSeis3DMatConsistentWithSeisInfo(self.seisdata[f], self.survinfo)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    ExportSeisSegy = QtWidgets.QWidget()
    gui = exportseissegy()
    gui.setupGUI(ExportSeisSegy)
    ExportSeisSegy.show()
    sys.exit(app.exec_())